# i75

[![Pipeline](https://github.com/andrewjw/i75/actions/workflows/build.yaml/badge.svg)](https://github.com/andrewjw/i75/actions/workflows/build.yaml)
[![PyPI version](https://badge.fury.io/py/i75.svg)](https://pypi.org/project/i75/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/i75)](https://pypi.org/project/i75/)
[![Coverage Status](https://coveralls.io/repos/github/andrewjw/i75/badge.svg?branch=main)](https://coveralls.io/github/andrewjw/i75?branch=main)
[![Documentation Status](https://readthedocs.org/projects/i75/badge/?version=latest)](https://i75.readthedocs.io/en/latest/?badge=latest)

A wrapper around Pimoroni's [interstate75](https://github.com/pimoroni/pimoroni-pico/blob/main/micropython/modules_py/interstate75.md) library which allows for running locally and easier testing.
